@@ -1,9 +1,8 @@
-__version__ = "0.2.2"
+__version__ = "0.2.3"
 
 
 from jax_metrics.losses import Loss
 from jax_metrics.metrics import AuxMetrics, Losses, Metric, Metrics, SumMetric
-from jax_metrics.types import Named
 
 from . import losses, metrics, regularizers
 
@@ -13,7 +12,6 @@ __all__ = [
     "Metrics",
     "Metric",
     "SumMetric",
-    "Named",
     "losses",
     "metrics",
     "regularizers",
